@@ -5,6 +5,7 @@ import time
 import subprocess
 from wiperf_poller.helpers.wirelessadapter import WirelessAdapter
 from wiperf_poller.helpers.os_cmds import DHCLIENT_CMD
+from wiperf_poller.helpers.timefunc import get_timestamp
 
 
 class DhcpTester(object):
@@ -42,45 +43,43 @@ class DhcpTester(object):
         The renewal duration is timed and the result (in mS) returned
 
         Usage:
-            tester_obj = DhcpTester(logger, debug=False)
+            tester_obj = DhcpTester(logger, platform)
             tester_obj.dhcp_renewal("wlan0")
 
         If the renewal fails, the wlan interface will be bounced and the whole script will exit
         """
 
         self.interface = interface
-
-        if mode == 'active':
-
-            # only do this if running active test
-            self.file_logger.debug("Releasing dhcp address on {}...".format(self.interface))
-
-            self.file_logger.info(
-                "Releasing dhcp address on {}...".format(self.interface))
-            try:
-                # also includes zombie process tidy-up
-                release_output = subprocess.check_output(
-                    "{} -r -v {} -pf /tmp/dhclient.pid 2>&1 && sudo kill $(cat /tmp/dhclient.pid) 2> /dev/null".format(DHCLIENT_CMD, self.interface), shell=True).decode()
-                # TODO: pattern search of: "DHCPRELEASE of 192.168.1.89 on wlan0"
-                self.file_logger.info("Address released.")
-            except Exception as ex:
-                self.file_logger.error("Issue releasing IP on interface: {}, issue {}".format(self.interface, ex))
-                # If release fails, bounce interface to recover - script will exit
-                self.bounce_interface(self.interface, self.file_logger)
-
+            
         start = 0.0
         end = 0.0
 
-        self.file_logger.info(
-            "Renewing dhcp address...(mode = {}, interface= {})".format(mode, self.interface))
+        self.file_logger.info("Renewing dhcp address...(mode = {}, interface= {})".format(mode, self.interface))
         try:
-            # includes zombie process cleanup
+            # renew address
             start = time.time()
-            subprocess.check_output(
-                "{} -v {} -pf /tmp/dhclient.pid 2>&1 && sudo kill $(cat /tmp/dhclient.pid) 2> /dev/null".format(DHCLIENT_CMD, self.interface), shell=True).decode()
-            end = time.time()
-            # TODO: pattern search for "bound to 192.168.1.89"
+
+            p = subprocess.Popen([DHCLIENT_CMD, '-v', self.interface, '-pf', '/tmp/dhclient.pid'], stderr=subprocess.PIPE)
+
+            while True:
+                line = p.stderr.readline()
+                self.file_logger.debug("dhcp: {}".format(line.decode().strip()))
+                if b'DHCPACK' in line:
+                    break
+                
+                # If we get here, DHCP ACK not seen - issue warning
+                if not line:
+                    self.file_logger.warning("dhcp: DHCP ACK not detected in renewal output.")
+                    break
+
+            end = time.time()          
             self.file_logger.info("Address renewed.")
+
+            try:
+                subprocess.check_output("pkill -9 -f 'dhclient.pid'", shell=True)
+            except subprocess.CalledProcessError as exc:
+                self.file_logger.info("Output from zombie processes kill: {}".format(exc))
+        
         except Exception as ex:
             self.file_logger.error("Issue renewing IP address: {}".format(ex))
 
@@ -111,20 +110,23 @@ class DhcpTester(object):
 
         if renewal_result:
 
-            column_headers = ['time', 'renewal_time_ms']
-
             results_dict = {
-                'time': int(time.time()),
-                'renewal_time_ms': renewal_result,
+                'time': get_timestamp(config_vars),
+                'renewal_time_ms': int(renewal_result),
             }
 
+            # define column headers for CSV
+            column_headers = list(results_dict.keys())
+
             # dump the results
             data_file = config_vars['dhcp_data_file']
             test_name = "DHCP"
-            exporter_obj.send_results(config_vars, results_dict, column_headers, data_file, test_name, self.file_logger)
-
-            self.file_logger.info("DHCP test ended.")
 
+            if exporter_obj.send_results(config_vars, results_dict, column_headers, data_file, test_name, self.file_logger):
+                self.file_logger.info("DHCP test ended.")
+            else:
+                self.file_logger.error("Error sending DHCP results")
+                tests_passed = False
         else:
             self.file_logger.error("DHCP test error - no results (check logs)")
             tests_passed = False
