@@ -7,6 +7,7 @@ import warnings
 import requests
 from requests.exceptions import HTTPError
 import urllib3
+from wiperf_poller.helpers.timefunc import get_timestamp
 
 class HttpTester(object):
     '''
@@ -67,7 +68,7 @@ class HttpTester(object):
         # return status code & elapsed duration in mS
         return (self.http_status_code, self.http_get_duration, self.http_server_response_time)
     
-    def run_tests(self, status_file_obj, config_vars, exporter_obj, watchd):
+    def run_tests(self, status_file_obj, config_vars, exporter_obj, watchd, check_correct_mode_interface,):
 
         self.file_logger.info("Starting HTTP tests...")
         status_file_obj.write_status_file("HTTP tests")
@@ -88,14 +89,24 @@ class HttpTester(object):
             if http_target == '':
                 continue
 
+            # check test will go over correct interface
+            target_hostname = http_target.split('/')[2]
+            if check_correct_mode_interface(target_hostname, config_vars, self.file_logger):
+                pass
+            else:
+                self.file_logger.error(
+                    "Unable to test http to {} as route to destination not over correct interface...bypassing http tests".format(http_target))
+                # we will break here if we have an issue as something bad has happened...don't want to run more tests
+                config_vars['test_issue'] = True
+                tests_passed = False
+                break
+
             self.file_logger.info("Starting http test to : {}".format(http_target))
 
             http_result = self.http_get(http_target)
 
             if http_result:
 
-                column_headers = ['time', 'http_index', 'http_target', 'http_get_time_ms', 'http_status_code', 'http_server_response_time_ms']
-
                 http_status_code = http_result[0]
                 http_get_time = http_result[1]
                 http_server_response_time = http_result[2]
@@ -109,14 +120,17 @@ class HttpTester(object):
                     self.file_logger.info("HTTP results: {}".format(result_str))
 
                     results_dict = {
-                        'time': int(time.time()),
-                        'http_index': http_index,
-                        'http_target': http_target,
-                        'http_get_time_ms': http_get_time,
-                        'http_status_code': http_status_code,
-                        'http_server_response_time_ms': http_server_response_time
+                        'time': get_timestamp(config_vars),
+                        'http_index': int(http_index),
+                        'http_target': str(http_target),
+                        'http_get_time_ms': int(http_get_time),
+                        'http_status_code': int(http_status_code),
+                        'http_server_response_time_ms': int(http_server_response_time)
                     }
 
+                    # define column headers for CSV
+                    column_headers = list(results_dict.keys())
+
                     # dump the results
                     data_file = config_vars['http_data_file']
                     test_name = "HTTP"
